

Aspects to test and refine:

https://stackoverflow.com/questions/73051271/can-i-use-only-nvidia-drivers-for-host-machine-of-docker-based-system

1. Do we need to install the nvidia-container-toolkit on the host?
